# Py Asoc

[![Checks][checks-shield]][checks-url]
[![Codecov][codecov-shield]][codecov-url]

[codecov-shield]: https://img.shields.io/codecov/c/github/mumblepins/py-asoc
[codecov-url]: https://app.codecov.io/gh/mumblepins/py-asoc
[checks-shield]: https://img.shields.io/github/actions/workflow/status/mumblepins/py-asoc/python-publish.yml?style=flat-square&branch=main
[checks-url]: https://github.com/mumblepins/py-asoc/actions/workflows/python-publish.yml
